==> neptune_ui-1.0.0.298.jar: com/tandbergtv/neptune/ui/realm/client/i18n/RealmConstants.java <==
package com.tandbergtv.neptune.ui.realm.client.i18n;

import com.google.gwt.i18n.client.Constants;

public interface RealmConstants extends Constants {

	// Component Name
	String componentDisplayName();

	// Menu Items
	String userMenuItem();
	String roleMenuItem();
	String haAdminMenuItem();


	// Role Table Messages
	String noRoleCheckBoxSelected();
	String roleDeleteConfirmation();

	// Role Details Page Constants
	String permissionsTableModuleHeading();
	String permissionsTablePermissionsHeading();

	// User View Messages
	String userListViewHeading();
	String externalUserListViewHeading();
	String userCreateExternalHeading();
	String userCreateHeading();
	String userDeleteConfirmation();
	String noUserCheckBoxSelectedError();
	String unauthorizedAccessError();
	String createExternalUserInvalidModeError();
	String createUserInvalidModeError();
	String viewUserInvalidAnchorError();

	// User Form Field Names
	String userName();
	String externalAuthentication();
	String password();
	String reenterPassword();
	String roles();
	String firstName();
	String lastName();
	String isActive();
	String email();
	String employeeId();
	String department();
	String location();
	String phone();
	String extension();

	// User Form Error Messages
	String passwordsDontMatchError();

	// Common Buttons
	String saveButton();
	String cancelButton();
	String createButton();
	String deleteButton();
	
	// Custom Buttons
	String createExternalUserButton();
	
	// User table
	String userNameColumn();
	String userFirstNameColumn();
	String userLastNameColumn();

	// External User table
	String externalUserCriteriaLabel();
	String externalUserSearchButton();
	String externalUserNameColumn();
	String externalFirstNameColumn();
	String externalLastNameColumn();
	
	/* Cluster Status Widget */
	String redundancyStatusActiveLabel();
	String redundancyStatusInactiveLabel();
	String redundancyStatusFailedLabel();
	String redundancyStatusActiveDescription();
	String redundancyStatusInactiveDescription();
	String redundancyStatusFailedDescription();
	String redundancyStatusDatabaseFailedDescription();
	String redundancyStatusAppServerFailedDescription();
	
	/* Cluster Status Portlet */
	String clusterStatusPortletHeader();
	String nodeStatus();
	String nodeName();
	String nodeMode();
	String nodeIP();
	
	/* HA Page */
	String haPageHeading();
	String manualFailOverButtonOFF();
	String manualFailOverButtonON();
	String failoverButton();
	String failoverConfirmation();
	String failoverSuccess();
	String haError();
	
	String userTab();

}

==> neptune_ui-2.0.0.408.jar: com/tandbergtv/neptune/ui/realm/client/i18n/RealmConstants.java <==
package com.tandbergtv.neptune.ui.realm.client.i18n;

import com.google.gwt.i18n.client.Constants;

public interface RealmConstants extends Constants {

	// Component Name
	String componentDisplayName();

	// Menu Items
	String userMenuItem();
	String roleMenuItem();
	String haAdminMenuItem();
	String settingsMenuItem();
	
	// General messages
	String genericError();
	
	// Settings messages
	String settingRequiresRestart();
	String inconsistentSettings();
	String settingsSaved();
	String restartRequired();
	String inconsistentSettingsLoginAlert();

	// Role Table Messages
	String noRoleCheckBoxSelected();
	String roleDeleteConfirmation();

	// Role Details Page Constants
	String permissionsTableModuleHeading();
	String permissionsTablePermissionsHeading();

	// User View Messages
	String userListViewHeading();
	String externalUserListViewHeading();
	String userCreateExternalHeading();
	String userCreateHeading();
	String userDeleteConfirmation();
	String noUserCheckBoxSelectedError();
	String unauthorizedAccessError();
	String createExternalUserInvalidModeError();
	String createUserInvalidModeError();
	String viewUserInvalidAnchorError();

	// User Form Field Names
	String userName();
	String externalAuthentication();
	String password();
	String reenterPassword();
	String roles();
	String firstName();
	String lastName();
	String isActive();
	String email();
	String employeeId();
	String department();
	String location();
	String phone();
	String extension();

	// User Form Error Messages
	String passwordsDontMatchError();

	// Common Buttons
	String saveButton();
	String cancelButton();
	String createButton();
	String deleteButton();
	
	// Custom Buttons
	String createExternalUserButton();
	
	// User table
	String userNameColumn();
	String userFirstNameColumn();
	String userLastNameColumn();

	// External User table
	String externalUserCriteriaLabel();
	String externalUserSearchButton();
	String externalUserNameColumn();
	String externalFirstNameColumn();
	String externalLastNameColumn();
	
	/* Cluster Status Widget */
	String redundancyStatusActiveLabel();
	String redundancyStatusInactiveLabel();
	String redundancyStatusFailedLabel();
	String redundancyStatusActiveDescription();
	String redundancyStatusInactiveDescription();
	String redundancyStatusFailedDescription();
	String redundancyStatusDatabaseFailedDescription();
	String redundancyStatusAppServerFailedDescription();
	
	/* Cluster Status Portlet */
	String clusterStatusPortletHeader();
	String nodeStatus();
	String nodeName();
	String nodeMode();
	String nodeIP();
	
	/* HA Page */
	String haPageHeading();
	String manualFailOverButtonOFF();
	String manualFailOverButtonON();
	String failoverButton();
	String failoverConfirmation();
	String failoverSuccess();
	String haError();
	
	String userTab();
	
	/* Settings Page */
	String settingsPageHeading();
	String settingsTabHeading();

}
